<?php

namespace Litecms\Company\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Company\Actions\MasterAction;
use Litecms\Company\Http\Requests\MasterActionRequest;
use Litecms\Company\Http\Resources\MasterResource;
use Litecms\Company\Models\Master;

/**
 * Admin web controller class.
 */
class MasterActionController extends BaseController
{

    /**
     * Action controller function for master.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(MasterActionRequest $request, Master $master, $action)
    {
        try {
            $request = $request->all();
            $master = MasterAction::run($action, $master, $request);

            $data = new MasterResource($master);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('company::master.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('company/master/' . $master->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('company/master/' . $master->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
