<?php

namespace Litecms\Company\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Company\Actions\YearAction;
use Litecms\Company\Http\Requests\YearActionRequest;
use Litecms\Company\Http\Resources\YearResource;
use Litecms\Company\Models\Year;

/**
 * Admin web controller class.
 */
class YearActionController extends BaseController
{

    /**
     * Action controller function for year.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(YearActionRequest $request, Year $year, $action)
    {
        try {
            $request = $request->all();
            $year = YearAction::run($action, $year, $request);

            $data = new YearResource($year);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('company::year.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('company/year/' . $year->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('company/year/' . $year->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
