<?php

namespace Litecms\Company\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Litecms\Company\Http\Requests\YearActionsRequest;
use Litecms\Company\Actions\YearActions;

/**
 * Admin web controller class.
 */
class YearActionsController extends BaseController
{

    /**
     * Action controller function for year.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(YearActionsRequest $request, $action)
    {
        try {
            $year = YearActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('company::year.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('company/year/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('company/year/' . $action))
                ->redirect();
        }
    }
}
