<?php

namespace Litecms\Company\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Company\Events\CompanyWorkflow as CompanyWorkflowEvent;
use Litecms\Company\Notifications\CompanyWorkflow as CompanyWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class CompanyWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(CompanyWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $company is submitted.
     *
     * @param CompanyWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(CompanyWorkflowEvent $event)
    {
        $client = $event->company->client;
        Notification::send($client, new CompanyWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $company is published.
     *
     * @param CompanyWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(CompanyWorkflowEvent $event)
    {
        $client = $event->company->client;
        Notification::send($client, new CompanyWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $company is approved.
     *
     * @param CompanyWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(CompanyWorkflowEvent $event)
    {
        $client = $event->company->client;
        Notification::send($client, new CompanyWorkflowNotification($event));
    }

    /**
     * Handles the $company workflow event as a listener.
     *
     * @param CompanyWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(CompanyWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
