<?php

namespace Litecms\Company\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Company\Events\YearWorkflow as YearWorkflowEvent;
use Litecms\Company\Notifications\YearWorkflow as YearWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class YearWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(YearWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $year is submitted.
     *
     * @param YearWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(YearWorkflowEvent $event)
    {
        $client = $event->year->client;
        Notification::send($client, new YearWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $year is published.
     *
     * @param YearWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(YearWorkflowEvent $event)
    {
        $client = $event->year->client;
        Notification::send($client, new YearWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $year is approved.
     *
     * @param YearWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(YearWorkflowEvent $event)
    {
        $client = $event->year->client;
        Notification::send($client, new YearWorkflowNotification($event));
    }

    /**
     * Handles the $year workflow event as a listener.
     *
     * @param YearWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(YearWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
