<?php
namespace Litecms\Company\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Litecms\Company\Events\YearAction as YearActionEvent;
use Litecms\Company\Models\Year;

class YearAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $year;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param YearActionEvent $year
     */
    public function __construct(YearActionEvent $year)
    {
        $this->action = $event->action;
        $this->year = $year;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Year Approved - ' . config('app.name'))
            ->view('company::year.email.action', ['data' => $this->year]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
