<?php

namespace Litecms\Company\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Litecms\Company\Models\Company;

class CompanyPolicy
{


    /**
     * Determine if the given user can view the company.
     *
     * @param Authenticatable $user
     * @param Company $company
     *
     * @return bool
     */
    public function view(Authenticatable $user, Company $company)
    {
        if ($authUser->canDo('company.company.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $company->is_owner;
    }

    /**
     * Determine if the given user can create a company.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('company.company.create');
    }

    /**
     * Determine if the given user can update the given company.
     *
     * @param Authenticatable $user
     * @param Company $company
     *
     * @return bool
     */
    public function update(Authenticatable $user, Company $company)
    {
        if ($user->canDo('company.company.edit') && $user->isAdmin()) {
            return true;
        }

        return $company->is_owner;
    }

    /**
     * Determine if the given user can delete the given company.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Company $company)
    {
        return $company->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
