<?php

namespace Litecms\Company\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Litecms\Company\Models\Master;

class MasterPolicy
{

    use MasterAction;

    /**
     * Determine if the given user can view the master.
     *
     * @param Authenticatable $user
     * @param Master $master
     *
     * @return bool
     */
    public function view(Authenticatable $user, Master $master)
    {
        if ($authUser->canDo('company.master.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $master->is_owner;
    }

    /**
     * Determine if the given user can create a master.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('company.master.create');
    }

    /**
     * Determine if the given user can update the given master.
     *
     * @param Authenticatable $user
     * @param Master $master
     *
     * @return bool
     */
    public function update(Authenticatable $user, Master $master)
    {
        if ($user->canDo('company.master.edit') && $user->isAdmin()) {
            return true;
        }

        return $master->is_owner;
    }

    /**
     * Determine if the given user can delete the given master.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Master $master)
    {
        return $master->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
